@@ -13,7 +13,7 @@ from typing import TYPE_CHECKING, Any, Dict, Iterator, List, Optional, Set, Unio
 
 import wcmatch.pathlib
 
-from ansiblelint.config import options
+from ansiblelint.config import BASE_KINDS, options
 from ansiblelint.constants import FileType
 
 if TYPE_CHECKING:
@@ -67,12 +67,17 @@ def expand_paths_vars(paths: List[str]) -> List[str]:
     return paths
 
 
-def kind_from_path(path: Path):
-    """Determine the file kind based on its name."""
+def kind_from_path(path: Path, base=False) -> str:
+    """Determine the file kind based on its name.
+
+    When called with base=True, it will return the base file type instead
+    of the explicit one. That is expected to return 'yaml' for any yaml files.
+    """
     # pathlib.Path.match patterns are very limited, they do not support *a*.yml
     # glob.glob supports **/foo.yml but not multiple extensions
-    pathex = wcmatch.pathlib.PurePath(path)
-    for entry in options.kinds:
+    pathex = wcmatch.pathlib.PurePath(path.absolute().resolve())
+    kinds = options.kinds if not base else BASE_KINDS
+    for entry in kinds:
         for k, v in entry.items():
             if pathex.globmatch(
                 v,
@@ -82,13 +87,20 @@ def kind_from_path(path: Path):
                     | wcmatch.pathlib.DOTGLOB
                 ),
             ):
-                return k
+                return str(k)
+
+    if base:
+        # Unknown base file type is default
+        return ""
+
     if path.is_dir():
         return "role"
 
     if str(path) == '/dev/stdin':
         return "playbook"
-    raise RuntimeError("Unable to determine file type for %s" % pathex)
+
+    # Unknown file types report a empty string (evaluated as False)
+    return ""
 
 
 class Lintable:
@@ -146,18 +158,21 @@ class Lintable:
             else:
                 self.dir = str(self.path.parent.resolve())
 
-    def __getitem__(self, item):
+        # determine base file kind (yaml, xml, ini, ...)
+        self.base_kind = kind_from_path(self.path, base=True)
+
+    def __getitem__(self, key: Any) -> Any:
         """Provide compatibility subscriptable support."""
-        if item == 'path':
+        if key == 'path':
             return str(self.path)
-        if item == 'type':
+        if key == 'type':
             return str(self.kind)
         raise NotImplementedError()
 
-    def get(self, item, default=None):
+    def get(self, key: Any, default: Any = None) -> Any:
         """Provide compatibility subscriptable support."""
         try:
-            return self.__getitem__(item)
+            return self.__getitem__(key)
         except NotImplementedError:
             return default
 
@@ -187,7 +202,7 @@ class Lintable:
 def get_yaml_files(options: Namespace) -> Dict[str, Any]:
     """Find all yaml files."""
     # git is preferred as it also considers .gitignore
-    git_command = ['git', 'ls-files', '-z', '*.yaml', '*.yml']
+    git_command = ['git', 'ls-files', '-z']
     _logger.info("Discovering files to lint: %s", ' '.join(git_command))
 
     out = None
@@ -216,6 +231,26 @@ def get_yaml_files(options: Namespace) -> Dict[str, Any]:
     return OrderedDict.fromkeys(sorted(out))
 
 
+def guess_project_dir() -> str:
+    """Return detected project dir or user home directory."""
+    try:
+        result = subprocess.run(
+            ["git", "rev-parse", "--show-toplevel"],
+            stderr=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            universal_newlines=True,
+            check=False,
+        )
+    except FileNotFoundError:
+        # if git is absent we use home directory
+        return str(Path.home())
+
+    if result.returncode != 0:
+        return str(Path.home())
+
+    return result.stdout.splitlines()[0]
+
+
 def expand_dirs_in_lintables(lintables: Set[Lintable]) -> None:
     """Return all recognized lintables within given directory."""
     all_files = get_yaml_files(options)
